breakaway is a wrapper for modern species richness estimation for modern datasets
breakaway(
input_data,
cutoff = NA,
output = NULL,
plot = NULL,
answers = NULL,
print = NULL,
...
)An input type that can be processed by convert()
The maximum frequency count to use for model fitting
Deprecated; only for backwards compatibility
Deprecated; only for backwards compatibility
Deprecated; only for backwards compatibility
Deprecated; only for backwards compatibility
Additional arguments will be ignored; this is for backward compatibility
An object of class alpha_estimate
breakaway presents an estimator of species richness that is
well-suited to the high-diversity/microbial setting. However, many microbial
datasets display more diversity than the Kemp-type models can permit. In
this case, the log-transformed WLRM diversity estimator of Rocchetti et. al.
(2011) is returned. The authors' experience suggests that some datasets that
require the log-transformed WLRM contain “false” diversity, that is,
diversity attributable to sequencing errors (via an inflated singleton
count). The authors encourage judicious use of diversity estimators when the
dataset may contain these errors, and recommend the use of
breakaway_nof1 as an exploratory tool in this case.
Willis, A. and Bunge, J. (2015). Estimating diversity via frequency ratios. Biometrics, 71(4), 1042–1049.
breakaway(apples)
#> Estimate of richness from method breakaway:
#> Estimate is 1552
#> with standard error 304.71
#> Confidence interval: (1201, 2517)
#>
breakaway(apples, plot = FALSE, output = FALSE, answers = TRUE)
#> Estimate of richness from method breakaway:
#> Estimate is 1552
#> with standard error 304.71
#> Confidence interval: (1201, 2517)
#>