This function implements the species richness estimation procedure outlined in Chao & Bunge (2002).
chao_bunge(input_data, cutoff = 10, output = NULL, answers = NULL)An input type that can be processed by convert() or a phyloseq object
The maximum frequency to use in fitting.
Deprecated; only for backwards compatibility
Deprecated; only for backwards compatibility
An object of class alpha_estimate, or alpha_estimates for phyloseq objects
chao_bunge(apples)
#> Estimate of richness from method Chao-Bunge:
#> Estimate is 1377
#> with standard error 64.43
#> Confidence interval: (1270, 1526)
#> Cutoff: 10