R/get_F_stat.R
get_F_stat.RdThis function calculates an F statistic for a test of null hypothesis LB = 0 (against an unrestricted alternative) where B is a vector of p fixed effects returned by betta() or betta_random() and L is an m x p matrix with linearly independent rows.
get_F_stat(fitted_betta, L)A list containing
The calculated F statistic