This function implements the sample richness estimate, which is the number of non-zero taxa per sample.
sample_richness(input_data)An input type that can be processed by convert() or a phyloseq object
An object of class alpha_estimate, or alpha_estimates for phyloseq objects
sample_richness(apples)
#> Estimate of richness from method Plug-in:
#> Estimate is 1000
#> with standard error 0
#> Confidence interval: (1000, 1000)
#>