R/tools_sample_size.R
sample_size_estimate.RdEstimate the sample size needed to do an unpaired one-way test using betta
sample_size_estimate(
control_group_est,
se_est,
diff = 5,
alpha = 0.05,
prop = 0.8,
samples = 20,
precision = 5
)An estimate of the alpha diversity parameter for the control group
An estimate of the (common) standard deviation
An estimate of the difference between the control and non-control groups
Minimum significance level desired
Desired power
Number of bootstrap resamples used to estimate the sample size. Increase for a more accurate estimate.
How much to increment the sample size as we try to increase the power
An estimate of the necessary sample size and some details