R/alpha_true.R
true_shannon.Rd
Calculate the true Shannon index based on proportions
true_shannon(input)
A vector of proportions.
The Shannon index of the population given by input.
This function is intended for population-level data. If you are dealing with a microbial sample, use DivNet instead.