R/alpha_true.R
true_simpson.Rd
Calculate the true Simpson index
true_simpson(input)
A vector of proportions.
The Simpson index of the population given by input.
This function is intended for population-level data. If you are dealing with a microbial sample, use DivNet instead.