R/richness_wlrm_t.R
wlrm_transformed.RdThis function implements the transformed version of the species richness estimation procedure outlined in Rocchetti, Bunge and Bohning (2011).
wlrm_transformed(
input_data,
cutoff = NA,
print = NULL,
plot = NULL,
answers = NULL
)An input type that can be processed by convert() or a phyloseq object
Maximum frequency count to use
Deprecated; only for backwards compatibility
Deprecated; only for backwards compatibility
Deprecated; only for backwards compatibility
An object of class alpha_estimate, or alpha_estimates for phyloseq objects
While robust to many different structures, model is almost always misspecified. The result is usually implausible diversity estimates with artificially low standard errors. Extreme caution is advised.
Rocchetti, I., Bunge, J. and Bohning, D. (2011). Population size estimation based upon ratios of recapture probabilities. Annals of Applied Statistics, 5.
wlrm_transformed(apples)
#> Estimate of richness from method wlrm_transformed:
#> Estimate is 1179
#> with standard error 28.18
#> Confidence interval: (1131, 1243)
#> Cutoff: 33
wlrm_transformed(apples, plot = FALSE, print = FALSE, answers = TRUE)
#> Estimate of richness from method wlrm_transformed:
#> Estimate is 1179
#> with standard error 28.18
#> Confidence interval: (1131, 1243)
#> Cutoff: 33