R/richness_wlrm_ut.R
wlrm_untransformed.RdThis function implements the untransformed version of the species richness estimation procedure outlined in Rocchetti, Bunge and Bohning (2011).
wlrm_untransformed(
input_data,
cutoff = NA,
print = NULL,
plot = NULL,
answers = NULL
)An input type that can be processed by convert() or a phyloseq object
Maximum frequency count to use
Deprecated; only for backwards compatibility
Deprecated; only for backwards compatibility
Deprecated; only for backwards compatibility
An object of class alpha_estimate, or alpha_estimates for phyloseq objects
This estimator is based on the negative binomial model and for that reason generally produces poor fits to microbial data. The result is usually artificially low standard errors. Caution is advised.
Rocchetti, I., Bunge, J. and Bohning, D. (2011). Population size estimation based upon ratios of recapture probabilities. Annals of Applied Statistics, 5.
wlrm_untransformed(apples)
#> Estimate of richness from method wlrm_untransformed:
#> Estimate is 1330
#> with standard error 77
#> Confidence interval: (1210, 1518)
#> Cutoff: 33